@@ -1,3 +1,4 @@
+"""Pyotr server."""
 from collections import namedtuple
 from functools import wraps
 from http import HTTPStatus
@@ -5,10 +6,11 @@ from importlib import import_module
 from inspect import iscoroutine
 from pathlib import Path
 from types import ModuleType
-from typing import Callable, Union, Optional
+from typing import Callable, Optional, Union
 from urllib.parse import urlsplit
 
 from openapi_core import create_spec
+from openapi_core.exceptions import OpenAPIError
 from openapi_core.schema.specs.models import Spec
 from openapi_core.shortcuts import RequestValidator, ResponseValidator
 from openapi_core.validation.exceptions import InvalidSecurity
@@ -26,6 +28,8 @@ Operation = namedtuple("Operation", "path method")
 
 
 class Application(Starlette):
+    """Pyotr server application."""
+
     def __init__(
         self,
         spec: Union[Spec, dict],
@@ -67,36 +71,44 @@ class Application(Starlette):
                 try:
                     endpoint_fn = getattr(base_module, name)
                 except AttributeError as e:
-                    raise RuntimeError(f"The function `{base_module}.{name}` does not exist!") from e
+                    raise RuntimeError(
+                        f"The function `{base_module}.{name}` does not exist!"
+                    ) from e
                 self.set_endpoint(endpoint_fn, operation_id=operation_id)
 
     def set_endpoint(self, endpoint_fn: Callable, *, operation_id: Optional[str] = None):
-        """ Sets endpoint function for a given `operationId`.
+        """Sets endpoint function for a given `operationId`.
 
-            If the `operation_id` is not given, it will try to determine it based on the function name.
+        If the `operation_id` is not given, it will try to determine it
+        based on the function name.
         """
         if operation_id is None:
             operation_id = endpoint_fn.__name__
         if self.enforce_case and operation_id not in self._operations:
-            operation_id_key = {snakecase(op_id): op_id for op_id in self._operations}.get(operation_id)
+            operation_id_key = {snakecase(op_id): op_id for op_id in self._operations}.get(
+                operation_id
+            )
         else:
             operation_id_key = operation_id
         try:
             operation = self._operations[operation_id_key]
-        except KeyError as e:
-            raise ValueError(f"Unknown operationId: {operation_id}.") from e
+        except KeyError as ex:
+            raise ValueError(f"Unknown operationId: {operation_id}.") from ex
 
         @wraps(endpoint_fn)
         async def wrapper(request: Request, **kwargs) -> Response:
             openapi_request = await StarletteOpenAPIRequest(request)
             validated_request = RequestValidator(
-                self.spec, custom_formatters=self.custom_formatters,
-                custom_media_type_deserializers=self.custom_media_type_deserializers
+                self.spec,
+                custom_formatters=self.custom_formatters,
+                custom_media_type_deserializers=self.custom_media_type_deserializers,
             ).validate(openapi_request)
             try:
                 validated_request.raise_for_errors()
             except InvalidSecurity as ex:
                 raise HTTPException(HTTPStatus.FORBIDDEN, "Invalid security.") from ex
+            except OpenAPIError as ex:
+                raise HTTPException(HTTPStatus.BAD_REQUEST, "Bad request") from ex
 
             response = endpoint_fn(request, **kwargs)
             if iscoroutine(response):
@@ -112,31 +124,34 @@ class Application(Starlette):
             # TODO: pass a list of operation IDs to specify which responses not to validate
             if self.validate_responses:
                 ResponseValidator(
-                    self.spec, custom_formatters=self.custom_formatters,
-                    custom_media_type_deserializers=self.custom_media_type_deserializers
+                    self.spec,
+                    custom_formatters=self.custom_formatters,
+                    custom_media_type_deserializers=self.custom_media_type_deserializers,
                 ).validate(
                     openapi_request, StarletteOpenAPIResponse(response)
                 ).raise_for_errors()
             return response
 
         for server_path in self._server_paths:
-            self.add_route(server_path + operation.path, wrapper, [operation.method], name=operation_id)
+            self.add_route(
+                server_path + operation.path, wrapper, [operation.method], name=operation_id
+            )
 
     def endpoint(self, operation_id: Union[Callable, str]):
-        """ Decorator for setting endpoints.
+        """Decorator for setting endpoints.
 
-            If used without arguments, it will try to determine the `operationId` based on the
-            decorated function name:
+        If used without arguments, it will try to determine the `operationId` based on the
+        decorated function name:
 
-                @app.endpoint
-                def foo_bar(request):
-                    # sets the endpoint for operationId fooBar
+            @app.endpoint
+            def foo_bar(request):
+                # sets the endpoint for operationId fooBar
 
-            Otherwise, the `operationId` can be set explicitly:
+        Otherwise, the `operationId` can be set explicitly:
 
-                @app.endpoint('fooBar'):
-                def my_endpoint():
-                    ...
+            @app.endpoint('fooBar'):
+            def my_endpoint():
+                ...
         """
         if callable(operation_id):
             self.set_endpoint(operation_id)
@@ -151,15 +166,13 @@ class Application(Starlette):
 
     @classmethod
     def from_file(cls, path: Union[Path, str], *args, **kwargs) -> "Application":
-        """ Creates an instance of the class by loading the spec from a local file.
-        """
+        """Creates an instance of the class by loading the spec from a local file."""
         spec = get_spec_from_file(path)
         return cls(spec, *args, **kwargs)
 
 
 def _load_module(name: str) -> ModuleType:
-    """ Helper function to load module based on its dotted-string name.
-    """
+    """Helper function to load module based on its dotted-string name."""
     try:
         module = import_module(name)
     except ModuleNotFoundError as e:
